pub struct EventOptions {
pub prevent_relationship_updates: bool,
pub prevent_persist: bool,
pub from_peer: Option<bool>,
}Expand description
Options that can be attached to an event
Fields
prevent_relationship_updates: boolWhen true, relationship cascades are skipped for this event. Used to prevent infinite loops during cascade processing.
prevent_persist: boolWhen true, the event is not persisted to durable backend. Used for events from durable backend (to avoid re-publishing).
from_peer: Option<bool>When true, this event was replicated from a peer server. Used to prevent re-broadcasting to peers and avoid cascade loops.